# [WIP] Neural Piano
## Hi-Fi neural MIDI piano synthesizer and MIDI renderer

***

## Installation

### pip and setuptools

```sh
# It is recommended that you upgrade pip and setuptools prior to install for max compatibility
!pip install --upgrade pip
!pip install --upgrade setuptools
```

### pip install

```sh
# The following command will install Neural Piano pip package
# Please note that Neural Piano requires Nvidia GPU with at least 40GB VRAM

!pip install -U neuralpiano
```

### Optional packages

#### Packages for midi_to_colab_audio module

```sh
# The following command will install packages for midi_to_colab_audio module

!sudo apt update -y
!sudo apt install fluidsynth
```

***

## Quick-start use example

```python
# Import main Neural Piano module
import neuralpiano
```

***

### Project Los Angeles
### Tegridy Code 2025
